@@ -8,7 +8,7 @@ def find(self, string='p4a', target='plone'):
     count = 0
     cleaned = []
     result = [[context.id, context]]
-    result.extend(self.ZopeFind(self, search_sub=True))
+    result.extend(context.ZopeFind(context, search_sub=True))
     for id_, object_ in result:
         has_missing_interfaces = r_find(object_, strings=strings)
         if has_missing_interfaces:
@@ -28,9 +28,11 @@ def r_find(self, strings=[]):
     file = StringIO.StringIO()
     pprint.pprint(provides.__dict__, file, depth=100000)
     value = file.getvalue()
-    return value
     found = []
     for string in strings:
         if string in value:
             found.append(string)
-    return found
+    if found:
+        return found, value
+    else:
+        return False
